# Beta sites don't have data dumps. They're included in this comment for the record:
# https://cs50.stackexchange.com
sites = [
    "https://stackoverflow.com",
    "https://3dprinting.stackexchange.com",
    "https://academia.stackexchange.com",
    "https://ai.stackexchange.com",
    "https://alcohol.stackexchange.com",
    "https://android.stackexchange.com",
    "https://anime.stackexchange.com",
    "https://apple.stackexchange.com",
    "https://arduino.stackexchange.com",
    "https://askubuntu.com",
    "https://astronomy.stackexchange.com",
    "https://aviation.stackexchange.com",
    "https://bicycles.stackexchange.com",
    "https://bioacoustics.stackexchange.com",
    "https://bioinformatics.stackexchange.com",
    "https://biology.stackexchange.com",
    "https://bitcoin.stackexchange.com",
    "https://blender.stackexchange.com",
    "https://boardgames.stackexchange.com",
    "https://bricks.stackexchange.com",
    "https://buddhism.stackexchange.com",
    "https://cardano.stackexchange.com",
    "https://chemistry.stackexchange.com",
    "https://chess.stackexchange.com",
    "https://chinese.stackexchange.com",
    "https://christianity.stackexchange.com",
    "https://civicrm.stackexchange.com",
    "https://codegolf.stackexchange.com",
    "https://codereview.stackexchange.com",
    "https://coffee.stackexchange.com",
    "https://communitybuilding.stackexchange.com",
    "https://computergraphics.stackexchange.com",
    "https://conlang.stackexchange.com",
    "https://cooking.stackexchange.com",
    "https://craftcms.stackexchange.com",
    "https://crafts.stackexchange.com",
    "https://crypto.stackexchange.com",
    "https://cs.stackexchange.com",
    "https://cseducators.stackexchange.com",
    "https://cstheory.stackexchange.com",
    "https://datascience.stackexchange.com",
    "https://dba.stackexchange.com",
    "https://devops.stackexchange.com",
    "https://diy.stackexchange.com",
    "https://drones.stackexchange.com",
    "https://drupal.stackexchange.com",
    "https://dsp.stackexchange.com",
    "https://earthscience.stackexchange.com",
    "https://ebooks.stackexchange.com",
    "https://economics.stackexchange.com",
    "https://electronics.stackexchange.com",
    "https://elementaryos.stackexchange.com",
    "https://ell.stackexchange.com",
    "https://emacs.stackexchange.com",
    "https://engineering.stackexchange.com",
    "https://english.stackexchange.com",
    "https://eosio.stackexchange.com",
    "https://es.stackoverflow.com",
    "https://esperanto.stackexchange.com",
    "https://ethereum.stackexchange.com",
    "https://expatriates.stackexchange.com",
    "https://expressionengine.stackexchange.com",
    "https://fitness.stackexchange.com",
    "https://freelancing.stackexchange.com",
    "https://french.stackexchange.com",
    "https://gamedev.stackexchange.com",
    "https://gaming.stackexchange.com",
    "https://gardening.stackexchange.com",
    "https://genai.stackexchange.com",
    "https://genealogy.stackexchange.com",
    "https://german.stackexchange.com",
    "https://gis.stackexchange.com",
    "https://graphicdesign.stackexchange.com",
    "https://ham.stackexchange.com",
    "https://hardwarerecs.stackexchange.com",
    "https://hermeneutics.stackexchange.com",
    "https://hinduism.stackexchange.com",
    "https://history.stackexchange.com",
    "https://homebrew.stackexchange.com",
    "https://hsm.stackexchange.com",
    "https://interpersonal.stackexchange.com",
    "https://iot.stackexchange.com",
    "https://iota.stackexchange.com",
    "https://islam.stackexchange.com",
    "https://italian.stackexchange.com",
    "https://ja.stackoverflow.com",
    "https://japanese.stackexchange.com",
    "https://joomla.stackexchange.com",
    "https://judaism.stackexchange.com",
    "https://korean.stackexchange.com",
    "https://langdev.stackexchange.com",
    "https://languagelearning.stackexchange.com",
    "https://latin.stackexchange.com",
    "https://law.stackexchange.com",
    "https://lifehacks.stackexchange.com",
    "https://linguistics.stackexchange.com",
    "https://literature.stackexchange.com",
    "https://magento.stackexchange.com",
    "https://martialarts.stackexchange.com",
    "https://math.stackexchange.com",
    "https://matheducators.stackexchange.com",
    "https://mathematica.stackexchange.com",
    "https://mathoverflow.net",
    "https://mattermodeling.stackexchange.com",
    "https://mechanics.stackexchange.com",
    "https://medicalsciences.stackexchange.com",
    "https://meta.stackexchange.com",
    "https://monero.stackexchange.com",
    "https://money.stackexchange.com",
    "https://movies.stackexchange.com",
    "https://music.stackexchange.com",
    "https://musicfans.stackexchange.com",
    "https://mythology.stackexchange.com",
    "https://networkengineering.stackexchange.com",
    "https://opendata.stackexchange.com",
    "https://opensource.stackexchange.com",
    "https://or.stackexchange.com",
    "https://outdoors.stackexchange.com",
    "https://parenting.stackexchange.com",
    "https://patents.stackexchange.com",
    "https://pets.stackexchange.com",
    "https://philosophy.stackexchange.com",
    "https://photo.stackexchange.com",
    "https://physics.stackexchange.com",
    "https://pm.stackexchange.com",
    "https://poker.stackexchange.com",
    "https://politics.stackexchange.com",
    "https://portuguese.stackexchange.com",
    "https://proofassistants.stackexchange.com",
    "https://psychology.stackexchange.com",
    "https://pt.stackoverflow.com",
    "https://puzzling.stackexchange.com",
    "https://quant.stackexchange.com",
    "https://quantumcomputing.stackexchange.com",
    "https://raspberrypi.stackexchange.com",
    "https://retrocomputing.stackexchange.com",
    "https://reverseengineering.stackexchange.com",
    "https://robotics.stackexchange.com",
    "https://rpg.stackexchange.com",
    "https://ru.stackoverflow.com",
    "https://rus.stackexchange.com",
    "https://russian.stackexchange.com",
    "https://salesforce.stackexchange.com",
    "https://scicomp.stackexchange.com",
    "https://scifi.stackexchange.com",
    "https://security.stackexchange.com",
    "https://serverfault.com",
    "https://sharepoint.stackexchange.com",
    "https://sitecore.stackexchange.com",
    "https://skeptics.stackexchange.com",
    "https://softwareengineering.stackexchange.com",
    "https://softwarerecs.stackexchange.com",
    "https://solana.stackexchange.com",
    "https://sound.stackexchange.com",
    "https://space.stackexchange.com",
    "https://spanish.stackexchange.com",
    "https://sports.stackexchange.com",
    "https://sqa.stackexchange.com",
    "https://stackapps.com",
    "https://stats.stackexchange.com",
    "https://stellar.stackexchange.com",
    "https://substrate.stackexchange.com",
    "https://superuser.com",
    "https://sustainability.stackexchange.com",
    "https://tex.stackexchange.com",
    "https://tezos.stackexchange.com",
    "https://tor.stackexchange.com",
    "https://travel.stackexchange.com",
    "https://tridion.stackexchange.com",
    "https://ukrainian.stackexchange.com",
    "https://unix.stackexchange.com",
    "https://ux.stackexchange.com",
    "https://vegetarianism.stackexchange.com",
    "https://vi.stackexchange.com",
    "https://video.stackexchange.com",
    "https://webapps.stackexchange.com",
    "https://webmasters.stackexchange.com",
    "https://woodworking.stackexchange.com",
    "https://wordpress.stackexchange.com",
    "https://workplace.stackexchange.com",
    "https://worldbuilding.stackexchange.com",
    "https://writing.stackexchange.com",
]

# For testing
# sites = ["https://stackoverflow.com"]
